@@ -19,18 +19,19 @@ import (
 	version "github.com/hashicorp/go-version"
 	"github.com/howeyc/gopass"
 	"github.com/pborman/getopt"
-	"github.com/percona/percona-toolkit/src/go/lib/config"
-	"github.com/percona/percona-toolkit/src/go/lib/versioncheck"
-	"github.com/percona/percona-toolkit/src/go/mongolib/proto"
-	"github.com/percona/percona-toolkit/src/go/mongolib/util"
-	"github.com/percona/percona-toolkit/src/go/pt-mongodb-summary/oplog"
-	"github.com/percona/percona-toolkit/src/go/pt-mongodb-summary/templates"
 	"github.com/pkg/errors"
 	"github.com/shirou/gopsutil/process"
 	log "github.com/sirupsen/logrus"
 	"go.mongodb.org/mongo-driver/bson/primitive"
 	"go.mongodb.org/mongo-driver/mongo"
 	"go.mongodb.org/mongo-driver/mongo/options"
+
+	"github.com/percona/percona-toolkit/src/go/lib/config"
+	"github.com/percona/percona-toolkit/src/go/lib/versioncheck"
+	"github.com/percona/percona-toolkit/src/go/mongolib/proto"
+	"github.com/percona/percona-toolkit/src/go/mongolib/util"
+	"github.com/percona/percona-toolkit/src/go/pt-mongodb-summary/oplog"
+	"github.com/percona/percona-toolkit/src/go/pt-mongodb-summary/templates"
 )
 
 const (
@@ -56,7 +57,7 @@ const (
 var (
 	Build     string = "2020-04-23"
 	GoVersion string = "1.14.1"
-	Version   string = "3.3.1"
+	Version   string = "3.4.0"
 	Commit    string
 
 	defaultConnectionTimeout = 3 * time.Second
@@ -93,6 +94,7 @@ type hostInfo struct {
 	ProcCreateTime   time.Time
 	ProcProcessCount int
 
+	CmdlineArgs []string
 	// Server Status
 	ProcessName    string
 	ReplicasetName string
@@ -326,6 +328,11 @@ func formatResults(ci *collectedInfo, format string) ([]byte, error) {
 			return nil, errors.Wrap(err, "cannot parse hosttemplateData section of the output template")
 		}
 
+		t = template.Must(template.New("cmdlineargsa").Parse(templates.CmdlineArgs))
+		if err := t.Execute(buf, ci.HostInfo); err != nil {
+			return nil, errors.Wrap(err, "cannot parse the command line args section of the output template")
+		}
+
 		t = template.Must(template.New("runningOps").Parse(templates.RunningOps))
 		if err := t.Execute(buf, ci.RunningOps); err != nil {
 			return nil, errors.Wrap(err, "cannot parse runningOps section of the output template")
@@ -400,6 +407,7 @@ func getHostInfo(ctx context.Context, client *mongo.Client) (*hostInfo, error) {
 		ProcPath:       pi.Path,
 		ProcUserName:   pi.UserName,
 		ProcCreateTime: pi.CreateTime,
+		CmdlineArgs:    cmdOpts.Argv,
 	}
 	if ss.Repl != nil {
 		i.ReplicasetName = ss.Repl.SetName
@@ -608,7 +616,8 @@ func getNodeType(ctx context.Context, client *mongo.Client) (string, error) {
 }
 
 func getOpCountersStats(ctx context.Context, client *mongo.Client, count int,
-	sleep time.Duration) (*opCounters, error) {
+	sleep time.Duration,
+) (*opCounters, error) {
 	oc := &opCounters{}
 	prevOpCount := &opCounters{}
 	ss := proto.ServerStatus{}
